import clsx from 'clsx';
import { OpenAPIDisclosureGroup } from '../OpenAPIDisclosureGroup';
import { OpenAPIRootSchema } from '../OpenAPISchema';
import { Section, SectionBody } from '../StaticSection';
/**
 * Display OpenAPI Models.
 */
export function OpenAPIModels(props) {
    var className = props.className, data = props.data, context = props.context;
    var models = data.models;
    var clientContext = {
        defaultInteractiveOpened: context.defaultInteractiveOpened,
        icons: context.icons,
        blockKey: context.blockKey,
    };
    if (!models.length) {
        return null;
    }
    return (<div className={clsx('openapi-models', className)}>
            <OpenAPIRootModelsSchema models={models} context={clientContext}/>
        </div>);
}
/**
 * Root schema for OpenAPI models.
 * It displays a single model or a disclosure group for multiple models.
 */
function OpenAPIRootModelsSchema(props) {
    var _a;
    var models = props.models, context = props.context;
    // If there is only one model, we show it directly.
    if (models.length === 1) {
        var schema = (_a = models === null || models === void 0 ? void 0 : models[0]) === null || _a === void 0 ? void 0 : _a.schema;
        if (!schema) {
            return null;
        }
        return (<Section>
                <SectionBody>
                    <OpenAPIRootSchema schema={schema} context={context}/>
                </SectionBody>
            </Section>);
    }
    // If there are multiple models, we use a disclosure group to show them all.
    return (<OpenAPIDisclosureGroup allowsMultipleExpanded icon={context.icons.chevronRight} groups={models.map(function (_a) {
            var name = _a.name, schema = _a.schema;
            return ({
                id: name,
                label: (<div className="openapi-response-tab-content" key={"model-".concat(name)}>
                        <span className="openapi-response-statuscode">{name}</span>
                    </div>),
                tabs: [
                    {
                        id: 'model',
                        body: (<Section className="openapi-section-models">
                                <SectionBody>
                                    <OpenAPIRootSchema schema={schema} context={context}/>
                                </SectionBody>
                            </Section>),
                    },
                ],
            });
        })}/>);
}
